==> apache-hop-2.1.0-src.tar.gz: apache-hop-2.1.0/plugins/transforms/databasejoin/src/main/java/org/apache/hop/pipeline/transforms/databasejoin/DatabaseJoinData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.databasejoin;

import org.apache.hop.core.database.Database;
import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

import java.sql.PreparedStatement;

public class DatabaseJoinData extends BaseTransformData implements ITransformData {
  public Database db;
  public PreparedStatement pstmt;

  IRowMeta outputRowMeta;
  IRowMeta lookupRowMeta;

  public int[] keynrs; // parameter value index in an input row...
  public Object[] notfound; // Values in case nothing is found...
  public boolean isCanceled;

  public DatabaseJoinData() {
    super();

    db = null;
    notfound = null;
  }
}

==> apache-hop-2.9.0-src.tar.gz: apache-hop-2.9.0/plugins/transforms/databasejoin/src/main/java/org/apache/hop/pipeline/transforms/databasejoin/DatabaseJoinData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.databasejoin;

import java.sql.PreparedStatement;
import org.apache.hop.core.database.Database;
import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;
import org.apache.hop.pipeline.transforms.databasejoin.cache.DatabaseCache;

public class DatabaseJoinData extends BaseTransformData implements ITransformData {
  public Database db;
  public PreparedStatement pstmt;
  public DatabaseCache cache;

  IRowMeta outputRowMeta;
  IRowMeta lookupRowMeta;

  public int[] keynrs; // parameter value index in an input row...
  public Object[] notfound; // Values in case nothing is found...
  public boolean isCanceled;

  public DatabaseJoinData() {
    super();

    db = null;
    notfound = null;
    cache = null;
  }
}
